import React, { useEffect } from 'react';
import Paper from '@material-ui/core/Paper';
import styled from 'styled-components';
import Grid from '@material-ui/core/Grid';
import LoadingSpinner from '../LoadingSpinner';
import noResources from '../../img/Pagina_vazia_Sem_publicar.png';
import ResourceCardFunction from '../ResourceCardFunction';
import IconButton from '@material-ui/core/IconButton';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import ArrowForwardIcon from '@material-ui/icons/ArrowForward';

export default function ResourceTemplate({ isLoading, resources, totalResources, currPage, handlePreviousPage, handleNextPage }) {
  const totalPages = parseInt(totalResources) === 0 ? 0 : Math.ceil(totalResources / 12) - 1; //Dividing by 12 because i want to cath total pages, and results per page is 12
  const topRef = React.useRef();

  useEffect(() => {
    topRef.current.scrollIntoView();
  }, [isLoading])

  return (
    <ResourcePaper elevation={4} square>
      <div ref={topRef} />
      <Title>
        Recursos encontrados ({totalResources})
      </Title>
      {
        isLoading ?
          <LoadingSpinner text='Carregando recursos...' />
          :
          <Grid container justify='center' alignItems='center' spacing={3}>
            {
              resources.length >= 1 ?
                resources.map((card) => {
                  return <Grid item key={new Date().toISOString() + card.id} >
                    <ResourceCardFunction
                      avatar={card.publisher ? card.publisher.avatar : ""}
                      id={card.id}
                      thumbnail={card.thumbnail}
                      type={card.object_type ? card.object_type : "Outros"}
                      title={card.name}
                      published={card.state === "published" ? true : false}
                      likeCount={card.likes_count}
                      liked={card.liked}
                      rating={card.review_average}
                      author={card.author}
                      tags={card.educational_stages}
                      href={"/recurso/" + card.id}
                      downloadableLink={card.default_attachment_location}
                    />
                  </Grid>
                })
                :
                <NoContentDiv>
                  <h3>
                    Desculpe, não há dados nessa página.
                  </h3>
                  <img src={noResources} alt='No cards' />
                </NoContentDiv>
            }
          </Grid>
      }
      {
        !isLoading &&
        <Grid container direction='row' alignItems='center' justify='center' spacing={3}>
          <Grid item>
            <StyledIconButton elevation={4} disabled={currPage === 0}>
              <IconButton onClick={handlePreviousPage} disabled={currPage === 0}>
                <ArrowBackIcon className='icon' />
              </IconButton>
            </StyledIconButton>
          </Grid>
          <Grid item>
            <ActualPage>
              {currPage}
            </ActualPage>...{totalPages}
          </Grid>
          <Grid item>
            <StyledIconButton elevation={4} disabled={currPage === totalPages}>
              <IconButton onClick={handleNextPage} disabled={currPage === totalPages}>
                <ArrowForwardIcon className='icon' />
              </IconButton>
            </StyledIconButton>
          </Grid>
        </Grid>
      }
    </ResourcePaper>
  )
};

const Title = styled.h4`
  text-transform: uppercase;
  font-weight: 500;
  text-align: left; 
  color: #ff7f00;
`
const NoContentDiv = styled.div`
  >h3{
    color: #ff7f00;
    text-align: center;
  }
`
const ActualPage = styled.span`
  color: #ff7f00;
`
const StyledIconButton = styled(Paper)` 
  border-radius: 50% !important;
  background-color: ${props => props.disabled ? "#666" : "#ff7f00"} !important;
  .icon{
    color: ${props => props.disabled ? "#d4d4d4" : "white"};
  }
`

const ResourcePaper = styled(Paper)`
  /* height: 150px; */
  text-align: center;
  background-color: #fff;
  margin-top: 5px;
  margin-bottom: 30px;
  padding: 0.5em 1em;
  color: #666;
  .textInfo{
    text-align: start;
  }
`;